Tc = -10;
M = 25;
turnPoint = .35;
ETA = .25; % For alpha and TStar plots
type = 5; % 1 = Budyko-Widiasih, 2 = Budyko-Widiasih Continuous, 3 = Abbot, 4 = Jormungand Instant, 5 = Jormungand Linear
% Alpha values were hard to find %
if type < 3
    A = 202;
    B = 1.9;
    C = 3.04;
    Q = 343;
    alpha_w = .32;
    alpha_s = .62;
    alpha_i = .6;
end

if type >= 3
    Q = 321;
    A = 170;
    B = 1.5;
    C = 2.25;
    alpha_w = .35;
    alpha_i = .45;
    alpha_s = .8;
end

%{
if type ==3
    Q = 321;
    A = 180;
    B = 1.5;
    C = 2.25;
    alpha_w = .32;
    alpha_i = .44;
    alpha_s = .74;
end
%}

X = 0:.001:1;
[n,m] = size(X);
Y = zeros(size(X));
Z = zeros(size(X));





% Solves for h

for i=1:m,
    Y(i) = h(A,B,C,Q,Tc,X(i),alpha_w,alpha_s,alpha_i,M,turnPoint,type);
end


% Solves for the bifurcation diagram

%{
for i=1:m,
    Y(i) = Aeta(X(i),Q,B,C,alpha_w,alpha_i,alpha_s,M,turnPoint,type,Tc);
end
%}

% Solves for the albedo function

%{
for i=1:m,
    Y(i) = alpha(X(i),ETA,alpha_w,alpha_s,alpha_i,M,turnPoint,type);
end
%}

% Simple Plot


plot(X,Y)
hline = refline(0,0);
set(hline,'Color','r');


% High Res (Poster) Plot of h.
%{
figure 
h_plot = plot(X,Y)
hline = refline(0,0);
set(hline,'Color','r');
xlabel('eta')
ylabel('h(eta)')
title('h(eta) vs eta (Simulation)')
set(gcf,'PaperUnits','inches','PaperPosition',[0 0 12 8])
set(0, 'DefaultTextFontSize',22)
set(0, 'DefaultAxesFontSize',22)
print -r600 -dpng hAbbot.png
%}

% Plot of h. Includes fancy LaTeX interpreter.
%{
hplot = figure(1);
h_plot = plot(X,Y);
hline = refline(0,0);
set(hline,'Color','r');
xlab = xlabel('\eta');
ylab = ylabel('h(\eta)');
titleStr = strcat('h(','\eta',') vs ',' \eta',' (Numerical Simulation, Instant Jormungand Albedo Function)');
tlab = title(titleStr);
set(xlab,'interpreter','tex');
set(ylab,'interpreter','tex');
set(tlab,'interpreter','tex');
set(hplot, 'Position', [0 0 800 600]);
set(0, 'DefaultTextFontSize',10);
set(0, 'DefaultAxesFontSize',10);
print -r150 -dpng hInstantNumSim.png
%}

% Plots the bifurcation diagram.
%{
hplot = figure(1);
h_plot = plot(Y,X);
hline = refline(0,0);
set(hline,'Color','r');
xlab = xlabel('A');
ylab = ylabel('Equilibrium \eta');
titleStr = strcat('Equilibrium ',' \eta',' vs ',' A',' (Instant)');
tlab = title(titleStr);
set(xlab,'interpreter','tex');
set(ylab,'interpreter','tex');
set(tlab,'interpreter','tex');
set(hplot, 'Position', [0 0 800 600]);
set(0, 'DefaultTextFontSize',10);
set(0, 'DefaultAxesFontSize',10);
print -r150 -dpng AbifurInstant.png
%}

%Plots TStarBar
%{
for i=1:m,
    Z(i) = TStarBar(A,B,Q,X(i),alpha_w,alpha_s,alpha_i,M,turnPoint,type);
end
plot(X,Z)
%}


% For plotting TStar at a given eta
%{
for i=1:10,
    for j=1:m
    Z(i) = TStar(X(j),A,B,C,Q,ETA,alpha_w,alpha_s,alpha_i,M,turnPoint,type );
    end
    plot(X,Z)
end
%}

%For plotting alpha at a given eta

%{
plot(X,Y)
axis([0 1 0 1]);
xlab = xlabel('y');
ylab = ylabel('\alpha');
titleStr = '\alpha vs y (Instant Jormungand Albedo Function, \eta=.25)';
tlab = title(titleStr);
set(xlab,'interpreter','tex');
set(ylab,'interpreter','tex');
set(tlab,'interpreter','tex');
set(hplot, 'Position', [0 0 800 600]);
set(0, 'DefaultTextFontSize',10);
set(0, 'DefaultAxesFontSize',10);
print -r150 -dpng albedoInstantEta25.png
%}